iniconfig: Brain-dead simple config-ini parsing
===============================================

Description
-----------

Brain-dead simple config-ini parsing

License
-------

Upstream Contact
----------------

https://pypi.org/project/iniconfig/

